package com.ruoyi.manage.mapper;

import java.util.List;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.manage.domain.BaseAreaUser;
import org.springframework.stereotype.Repository;
/**
 * 机场区域用户绑定Mapper接口
 *
 * @author wangh
 * @date 2024-01-25
 */
@Repository
public interface BaseAreaUserMapper
{
    /**
     * 查询机场区域用户绑定
     *
     * @param objid 机场区域用户绑定主键
     * @return 机场区域用户绑定
     */
    public BaseAreaUser selectBaseAreaUserByObjid(Long objid);

    /**
     * 查询机场区域用户绑定列表
     *
     * @param baseAreaUser 机场区域用户绑定
     * @return 机场区域用户绑定集合
     */
    public List<BaseAreaUser> selectBaseAreaUserList(BaseAreaUser baseAreaUser);

    /**
     * 新增机场区域用户绑定
     *
     * @param baseAreaUser 机场区域用户绑定
     * @return 结果
     */
    public int insertBaseAreaUser(BaseAreaUser baseAreaUser);

    /**
     * 修改机场区域用户绑定
     *
     * @param baseAreaUser 机场区域用户绑定
     * @return 结果
     */
    public int updateBaseAreaUser(BaseAreaUser baseAreaUser);

    /**
     * 删除机场区域用户绑定
     *
     * @param objid 机场区域用户绑定主键
     * @return 结果
     */
    public int deleteBaseAreaUserByObjid(Long objid);

    /**
     * 批量删除机场区域用户绑定
     *
     * @param objids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBaseAreaUserByObjids(String[] objids);

    List<SysUser> selectSysUser();
}
